summaryrefslogtreecommitdiffstats
path: root/kugar
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2024-03-09 18:58:02 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2024-03-17 21:16:45 +0900
commit7a7827396f90ad06945cd5a367f93d8ffd380e0f (patch)
treec812fa6c9a336fac31583724535fbcf8fd0e5ae0 /kugar
parentea7a0b4d73337e0e30678300466e668179241348 (diff)
downloadkoffice-7a7827396f90ad06945cd5a367f93d8ffd380e0f.tar.gz
koffice-7a7827396f90ad06945cd5a367f93d8ffd380e0f.zip
Replace Qt with TQt
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'kugar')
-rw-r--r--kugar/README8
-rw-r--r--kugar/lib/mreportviewer.cpp2
-rw-r--r--kugar/lib/mreportviewer.h4
3 files changed, 7 insertions, 7 deletions
diff --git a/kugar/README b/kugar/README
index 6c6372a9..4ad64dfe 100644
--- a/kugar/README
+++ b/kugar/README
@@ -22,7 +22,7 @@ ABOUT KUGAR:
Current features:
* KDE GUI report designer.
-* Qt report viewer widget for previewing reports from within a Qt application
+* TQt report viewer widget for previewing reports from within a TQt application
(WYSIWYG).
* KDE report viewer widget that utilizes KDE print dialog
* KDE report viewer utility.
@@ -38,7 +38,7 @@ Current features:
* Grand totals: count, sum, average, variance and standard deviation.
* Report print progress and cancellation.
* Report rendering progress and cancellation.
-* Complete implementation of (Qt) printer setup options.
+* Complete implementation of (TQt) printer setup options.
* Additional formatting (negative numbers, currency, commas for numbers and
dates).
* Direct database support.
@@ -53,8 +53,8 @@ REQUIREMENTS:
The following items must be installed prior to building Kugar:
-1. Qt version 3.1+ - http://www.trolltech.com
-2. KDE 3.1.0+ - http://www.kde.org
+1. TQt
+2. TDE
BUILDING KUGAR:
diff --git a/kugar/lib/mreportviewer.cpp b/kugar/lib/mreportviewer.cpp
index bb8b1135..a606aad6 100644
--- a/kugar/lib/mreportviewer.cpp
+++ b/kugar/lib/mreportviewer.cpp
@@ -1,5 +1,5 @@
/***************************************************************************
- mreportviewer.cpp - Kugar QT report viewer widget
+ mreportviewer.cpp - Kugar TQt report viewer widget
-------------------
begin : Fri Aug 13 1999
copyright : (C) 1999 by Mutiny Bay Software
diff --git a/kugar/lib/mreportviewer.h b/kugar/lib/mreportviewer.h
index d4061fad..accb69f0 100644
--- a/kugar/lib/mreportviewer.h
+++ b/kugar/lib/mreportviewer.h
@@ -1,5 +1,5 @@
/***************************************************************************
- mreportviewer.h - Kugar QT report viewer widget
+ mreportviewer.h - Kugar TQt report viewer widget
-------------------
begin : Fri Aug 13 1999
copyright : (C) 1999 by Mutiny Bay Software
@@ -31,7 +31,7 @@ class KPrinter;
/** Application reference, required for event processing */
extern TQApplication *mAppRef;
/**Kugar QT report viewer widget
*@author Mutiny Bay Software
*/
@@ -31,7 +31,7 @@ class KPrinter;
/** Application reference, required for event processing */
extern TQApplication *mAppRef;
-/**Kugar QT report viewer widget
+/**Kugar TQt report viewer widget
*@author Mutiny Bay Software
*/